==> add-content-workflow-angularjs-1.1.27.tgz: package/source/app/add-content-tag-selection/add-content-tag-selection.component.ts <==
export default class AddContentTagSelectionComponent {
    workflow: any;

    static config = {
        selector: 'addContentTagSelection',
        template: `
        <div layout="column" class="add-content-workflow__tag-selection">
            <label class="add-content-workflow__add flux-text--title" ng-if="$ctrl.workflow.currentStep === 'source'">{{::$ctrl.AddContentTranslate.get('add-content-workflow__source-step--tags-label')}}</label>
            <label class="mw-active-label" ng-if="$ctrl.workflow.currentStep === 'source'">{{::$ctrl.AddContentTranslate.get('add-content-workflow__source-step--tags-for-all-label')}}</label>
            <label class="flux-text--title" ng-if="$ctrl.workflow.currentStep === 'details'">{{::$ctrl.AddContentTranslate.get('add-content-workflow__details-step--tags-label')}}</label>
            <div class="add-content-workflow__tag-selection--tag-container">
                <div>
                    <md-button 
                        class="mw-button mw-button--has-icon" 
                        ng-click="$ctrl.showTagSelectModal($event)" 
                        ng-disabled="$ctrl.workflow.loadingTags || $ctrl.workflow.savingAddContent" 
                        style="margin: 8px 0">
                        <md-progress-circular ng-if="$ctrl.workflow.loadingTags"
                            md-diameter="16px"
                            style="margin: 8px auto"></md-progress-circular>
                        <mw-icon ng-if="!$ctrl.workflow.loadingTags" svg-icon="content:ic_add_circle_outline_24px"></mw-icon>
                        <span ng-if="!$ctrl.workflow.loadingTags">
                        {{::$ctrl.AddContentTranslate.get('add-content-workflow__details-step--add-tags-button')}}</span>
                    </md-button>
                </div>
                <md-chips readonly="true" md-removable="true" ng-model="$ctrl.workflow.documentTags" md-on-remove="$ctrl.deselectTag($chip)">
                    <md-chip-template>
                    {{ $chip.substring(0,25) }}<span ng-if="$chip.length > 25">...</span>
                        <md-tooltip ng-if="$chip.length > 25">{{ $chip }}</md-tooltip>
                    </md-chip-template>
                </md-chips>
            </div>
        </div>
        `,
        controller: AddContentTagSelectionComponent,
        bindings: {
            workflow: '<'
        },
        
    };
    constructor(
        private $mdDialog,
        private AddContentTranslate,
        
    ) {
    }
    deselectTag = (display) => {
        let tags = this.workflow.tags
        for(let i = 0; i < tags.length; i++){
            if(tags[i].display === display){
                tags[i].selected = false
                return
            }
        }
      };
          
    showTagSelectModal = (event) => {
        const parent = angular.element(document.getElementsByClassName('md-dialog-container')[0]);

        this.$mdDialog.show({
            parent,
            multiple: true,
            autoWrap: false,
            bindToController: true,
            fullscreen: true,
            targetEvent: event,
            locals: {
                inputs: angular.copy(this.workflow.tags)
            },
            template: `
                <md-dialog class="mw-mini-modal mw-mini-modal--maximized" aria-label="" layout="column">
                    <input-selector-dialog class="mw-mini-modal-wrapper" inputs="$ctrl.inputs" layout="column"></input-selector-dialog>
                </md-dialog>
            `,
            controller: 'MwMiniModalDialogController',
            controllerAs: '$ctrl',
        })
            .then(
                (inputs) => {
                    this.workflow.tags = inputs;
                    this.workflow.documentTags = this.workflow.tags
                    .filter((tag)=> tag.selected)
                    .map((tag)=>{
                        return tag.display
                    })
                }
            )
            .catch(error => {
                if (error) {
                    console.error('Error applying tags to add content', error);
                }
            });
    };
    cancel() {
        this.$mdDialog.cancel();
    }
}

==> add-content-workflow-angularjs-1.4.0.tgz: package/source/app/add-content-tag-selection/add-content-tag-selection.component.ts <==
export default class AddContentTagSelectionComponent {
    workflow: any;

    static config = {
        selector: 'addContentTagSelection',
        template: `
        <div layout="column" class="add-content-workflow__tag-selection">
            <label class="add-content-workflow__add flux-text--title" ng-if="$ctrl.workflow.currentStep === 'source'">{{::$ctrl.AddContentTranslate.get('add-content-workflow__source-step--tags-label')}}</label>
            <label class="mw-active-label" ng-if="$ctrl.workflow.currentStep === 'source'">{{::$ctrl.AddContentTranslate.get('add-content-workflow__source-step--tags-for-all-label')}}</label>
            <label class="flux-text--title" ng-if="$ctrl.workflow.currentStep === 'details'">{{::$ctrl.AddContentTranslate.get('add-content-workflow__details-step--tags-label')}}</label>
            <div class="add-content-workflow__tag-selection--tag-container">
                <div>
                    <md-button 
                        class="mw-button mw-button--has-icon" 
                        ng-click="$ctrl.showTagSelectModal($event)" 
                        ng-disabled="$ctrl.workflow.loadingTags || $ctrl.workflow.savingAddContent || $ctrl.workflow.skipChecked"
                        style="margin: 8px 0">
                        <md-progress-circular ng-if="$ctrl.workflow.loadingTags"
                            md-diameter="16px"
                            style="margin: 8px auto"></md-progress-circular>
                        <mw-icon ng-if="!$ctrl.workflow.loadingTags" svg-icon="content:ic_add_circle_outline_24px"></mw-icon>
                        <span ng-if="!$ctrl.workflow.loadingTags">
                        {{::$ctrl.AddContentTranslate.get('add-content-workflow__details-step--add-tags-button')}}</span>
                    </md-button>
                </div>
                <md-chips readonly="true" md-removable="true" ng-model="$ctrl.workflow.documentTags" md-on-remove="$ctrl.deselectTag($chip)">
                    <md-chip-template>
                    {{ $chip.substring(0,25) }}<span ng-if="$chip.length > 25">...</span>
                        <md-tooltip ng-if="$chip.length > 25">{{ $chip }}</md-tooltip>
                    </md-chip-template>
                </md-chips>
            </div>
        </div>
        `,
        controller: AddContentTagSelectionComponent,
        bindings: {
            workflow: '<'
        },
        
    };
    constructor(
        private $mdDialog,
        private AddContentTranslate,
        
    ) {
    }
    deselectTag = (display) => {
        let tags = this.workflow.tags
        for(let i = 0; i < tags.length; i++){
            if(tags[i].display === display){
                tags[i].selected = false
                return
            }
        }
      };
          
    showTagSelectModal = (event) => {
        const parent = angular.element(document.getElementsByClassName('md-dialog-container')[0]);

        this.$mdDialog.show({
            parent,
            multiple: true,
            autoWrap: false,
            bindToController: true,
            fullscreen: true,
            targetEvent: event,
            locals: {
                inputs: angular.copy(this.workflow.tags),
                workflow: this.workflow
            },
            template: `
                <md-dialog class="mw-mini-modal mw-mini-modal--maximized" aria-label="" layout="column">
                    <input-selector-dialog workflow="$ctrl.workflow" class="mw-mini-modal-wrapper" inputs="$ctrl.inputs" layout="column"></input-selector-dialog>
                </md-dialog>
            `,
            controller: 'MwMiniModalDialogController',
            controllerAs: '$ctrl',
        })
            .then(
                (inputs) => {
                    this.workflow.tags = inputs;
                    this.workflow.documentTags = this.workflow.tags
                    .filter((tag)=> tag.selected)
                    .map((tag)=>{
                        return tag.display
                    })
                }
            )
            .catch(error => {
                if (error) {
                    console.error('Error applying tags to add content', error);
                }
            });
    };
    cancel() {
        this.$mdDialog.cancel();
    }
}
